==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_variables.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)44 1.10 src/ll/config_editor/cgi-bin/show_tab_panel_variables.pl, ll.config, ll_rrur2, rrur21042a 1/12/10 03:37:55\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(1);

my @editable_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_variables"}->[0]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_variables.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
if(!defined($dbh))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => DBI->errstr);
	print $tmpl->output;
	exit 1;
}
my $sql_str = "select clusterID,name from TLL_Cluster;";
my $sth = $dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down = ();
my $default_cluster_id = undef;
if($sth->fetch())
{
	$default_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down, \%pair;
	}
}
$tmpl->param(pull_down => \@pull_down);

foreach my $table (@editable_tables_by_clusterID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table." limit 1";
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);

	if(defined($default_cluster_id))
	{
		$sql_str="select * from ".$table." where clusterID=".$default_cluster_id;
		
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		my $idx = 0;
		my @rows = ();
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			# for table TLLR_CFGVars
			my @columns = ();
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				my %col_item = (name => $sth->{NAME}->[$i],
						title => $sth->{NAME}->[$i],
						value => $ary_ref->[$i],
						orig_name => "orig-".$sth->{NAME}->[$i],
						orig_value => $ary_ref->[$i]);
				push @columns, \%col_item;
			}
			
			my %row_item = (columns => \@columns);
			push @rows, \%row_item;
			$idx++;
		}
		$tmpl->param($table."_rows" => \@rows);
		$tmpl->param($table."-id" => $default_cluster_id);
	}
}

$sth->finish();
$dbh->disconnect();

print "Content-type: text/html\n\n";
print $tmpl->output;

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_variables.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)44 1.11 src/ll/config_editor/cgi-bin/show_tab_panel_variables.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:37:44\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(1);

my @editable_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_variables"}->[0]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_variables.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

my $dbh = get_dbh(1);
if(!defined($dbh))
{
	error_and_exit($dbh->errstr);
}
my $sql_str = "select clusterID,name from TLL_Cluster;";
my $sth = $dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down = ();
my $default_cluster_id = undef;
if($sth->fetch())
{
	$default_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down, \%pair;
	}
}
$tmpl->param(pull_down => \@pull_down);

foreach my $table (@editable_tables_by_clusterID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);

	if(defined($default_cluster_id))
	{
		$sql_str="select * from ".$table." where clusterID=".$default_cluster_id;
		
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		my $idx = 0;
		my @rows = ();
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			# for table TLLR_CFGVars
			my @columns = ();
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				my %col_item = (name => $sth->{NAME}->[$i],
						title => $sth->{NAME}->[$i],
						value => $ary_ref->[$i],
						orig_name => "orig-".$sth->{NAME}->[$i],
						orig_value => $ary_ref->[$i]);
				push @columns, \%col_item;
			}
			
			my %row_item = (columns => \@columns);
			push @rows, \%row_item;
			$idx++;
		}
		$tmpl->param($table."_rows" => \@rows);
		$tmpl->param($table."-id" => $default_cluster_id);
	}
}

$sth->finish();
$dbh->disconnect();

print "Content-type: text/html\n\n";
print $tmpl->output;
